@@ -39,7 +39,7 @@ impl<T: MmapBytesReader + ?Sized> MmapBytesReader for Box<T> {
 }
 
 // Handle various forms of input bytes
-pub(crate) enum ReaderBytes<'a> {
+pub enum ReaderBytes<'a> {
     Borrowed(&'a [u8]),
     Owned(Vec<u8>),
     Mapped(memmap::Mmap),
@@ -55,3 +55,16 @@ impl std::ops::Deref for ReaderBytes<'_> {
         }
     }
 }
+
+impl<'a, T: 'a + MmapBytesReader> From<&'a T> for ReaderBytes<'a> {
+    fn from(m: &'a T) -> Self {
+        match m.to_bytes() {
+            Some(s) => ReaderBytes::Borrowed(s),
+            None => {
+                let f = m.to_file().unwrap();
+                let mmap = unsafe { memmap::Mmap::map(f).unwrap() };
+                ReaderBytes::Mapped(mmap)
+            }
+        }
+    }
+}
